# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/sindr',
                'doc_host': 'https://$GIT_USER_NAME.github.io',
                'git_url': 'https://github.com/$GIT_USER_NAME/sindr',
                'lib_path': 'sindr'},
  'syms': { 'sindr.core': { 'sindr.core.get_config': ('core.html#get_config', 'sindr/core.py'),
                            'sindr.core.get_samplesheet': ('core.html#get_samplesheet', 'sindr/core.py'),
                            'sindr.core.set_env_variables': ('core.html#set_env_variables', 'sindr/core.py'),
                            'sindr.core.show_project_env_vars': ('core.html#show_project_env_vars', 'sindr/core.py')},
            'sindr.hello_world': { 'sindr.hello_world.cli': ('hello_world.html#cli', 'sindr/hello_world.py'),
                                   'sindr.hello_world.hello_world': ('hello_world.html#hello_world', 'sindr/hello_world.py')},
            'sindr.seq_tools': {},
            'sindr.some_string': {}}}
